#!/usr/bin/python2.5
#
# magtek_read.py:  Driver for USB HID Mag-Tek MSR.
# 
#                  uWink, Inc.
#                  Manuel F Martinez <manuel@uwink.com>
#                  Van Nuys, CA
#                  Wed 11, February 2009
#
#                  STATUS: *** Working ***
#

import array
import sys
import time
import array 
import os
libsdir = os.getcwd() + '/.libs'
if os.path.isdir(libsdir) and os.path.isfile(libsdir + '/_hid.so'):
  sys.path.insert(0, libsdir)

from hid import *

# Global variables
track = '\xff000001\xff000030'
path = array.array('b',track)
buffer = []
cbuffer = []

##### F U N C T I O N S #####

# Get HID Report
def get_msr(hid):
  global buffer, cbuffer


  #ret, buffer = hid_get_input_report(hid, path, 337)
  ret = hid_set_idle(hid, 4, 2)
  if ret != HID_RET_SUCCESS:
    sys.stderr.write("hid_set_idle failed with return code %d.\n" % ret)

  ret, buffer = hid_interrupt_read(hid, 0x81, 110, 4000)

  if ret != HID_RET_SUCCESS:
    sys.stderr.write("hid_get_input_report failed with return code %d.\n" % ret)
  else:
    cbuffer = array.array('b',buffer)
  return

##### M A I N #####

def main():
  # Setup debug verbosity
  hid_set_debug(HID_DEBUG_ALL)
  hid_set_debug_stream(sys.stderr)
  hid_set_usb_debug(0)

  # Init HID
  ret = hid_init()
  if ret != HID_RET_SUCCESS:
    sys.stderr.write("hid_init failed with return code %d.\n" % ret)

  hid = hid_new_HIDInterface()
  matcher = HIDInterfaceMatcher()
  matcher.vendor_id = 0x0801
  matcher.product_id = 0x0002

  # Open device -- Try HID then Keyboard mode
  ret = hid_force_open(hid, 0, matcher, 3)
  if ret != HID_RET_SUCCESS:
    sys.stderr.write("hid_force_open failed with return code %d.\n" % ret)

  get_msr(hid)
  print "\n\n*********************"
  print "BUFFER  ", buffer
  print "CBUFFER ", cbuffer
  print "*********************\n\n"

  # Close device
  ret = hid_close(hid)
  if ret != HID_RET_SUCCESS:
    sys.stderr.write("hid_close failed with return code %d.\n" % ret)

  hid_cleanup()

if __name__ == '__main__':
  main()

# COPYRIGHT --
#
# This file is part of libhid, a user-space HID access library.
# libhid is (c) 2003-2005
#   Martin F. Krafft <libhid@pobox.madduck.net>
#   Charles Lepple <clepple@ghz.cc>
#   Arnaud Quette <arnaud.quette@free.fr> && <arnaud.quette@mgeups.com>
# and distributed under the terms of the GNU General Public License.
# See the file ./COPYING in the source distribution for more information.
#
# Modified by:
# Manuel Martinez <manuel@uwink.com> uWink, Inc.
#
# THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES
# OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
