#!/usr/bin/python2.5
#
# magtek_utility.py:  Utility for USB Mag-Tek MSR, reads
#                     and changes the MSR mode by libhid.
# 
#                      uWink, Inc.
#                      Manuel F Martinez <manuel@uwink.com>
#                      Van Nuys, CA
#                      Mon 15, December 2008
#
#                      STATUS: *** Working ***
#

import sys
import time
import array 
import os
libsdir = os.getcwd() + '/.libs'
if os.path.isdir(libsdir) and os.path.isfile(libsdir + '/_hid.so'):
    sys.path.insert(0, libsdir)

from hid import *

# Global variables
gsoftware_id       =   '\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
ginterface_type    =   '\x00\x01\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
# sinterface_type[0]: HID Mode   ---   sinterface_type[1]: Keyboard Mode
sinterface_type    = [ '\x01\x02\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00',  
                       '\x01\x02\x10\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00' ]
reset_device       =   '\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
path = [0]
buffer = []
cbuffer = []

##### F U N C T I O N S #####

# Set HID Report
def set_msr(hid, cmd):
    ret = hid_set_feature_report(hid, path, cmd)
    if ret != HID_RET_SUCCESS:
        sys.stderr.write("hid_set_feature_report failed with return code %d.\n" % ret)
    time.sleep(2)
    return

# Get HID Report
def get_msr(hid):
    global buffer, cbuffer
    ret, buffer = hid_get_feature_report(hid, path, 24)
    if ret != HID_RET_SUCCESS:
        sys.stderr.write("hid_get_feature_report failed with return code %d.\n" % ret)
    else:
        cbuffer = array.array('b',buffer)
    return

##### M A I N #####

def main():
    print "Mag-Tek utility for USB Elo card reader - uWink, Inc."

    # Setup debug verbosity
    hid_set_debug(HID_DEBUG_ALL)
    hid_set_debug_stream(sys.stderr)
    hid_set_usb_debug(0)

    # Init HID
    ret = hid_init()
    if ret != HID_RET_SUCCESS:
        sys.stderr.write("hid_init failed with return code %d.\n" % ret)

    hid = hid_new_HIDInterface()
    matcher = HIDInterfaceMatcher()
    matcher.vendor_id = 0x0801
    matcher.product_id = 0x0002

    # Open device -- Try HID then Keyboard mode
    ret = hid_force_open(hid, 0, matcher, 3)
    if ret != HID_RET_SUCCESS:
        print "Failed to open HID Mode\n"
        matcher.product_id = 0x0001
        ret = hid_force_open(hid, 0, matcher, 3)
        if ret != HID_RET_SUCCESS:
            print "Failed to open Keyboard Mode\n"
            sys.stderr.write("hid_force_open failed with return code %d.\n" % ret)
    if ret == HID_RET_SUCCESS:
        # Prompt user to change mode
        print "Setting mode\n"
        set_msr(hid, ginterface_type)
        get_msr(hid)
        if cbuffer[2] == 1:
            # Change mode
            print "Changing mode\n"
            set_msr(hid, sinterface_type[1])
            set_msr(hid, reset_device)

    # Close device
    ret = hid_close(hid)
    if ret != HID_RET_SUCCESS:
        sys.stderr.write("hid_close failed with return code %d.\n" % ret)

    hid_cleanup()

if __name__ == '__main__':
    main()

# COPYRIGHT --
#
# This file is part of libhid, a user-space HID access library.
# libhid is (c) 2003-2005
#   Martin F. Krafft <libhid@pobox.madduck.net>
#   Charles Lepple <clepple@ghz.cc>
#   Arnaud Quette <arnaud.quette@free.fr> && <arnaud.quette@mgeups.com>
# and distributed under the terms of the GNU General Public License.
# See the file ./COPYING in the source distribution for more information.
#
# Modified by:
# Manuel Martinez <manuel@uwink.com> uWink, Inc.
#
# THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES
# OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
